@@ -37,6 +37,8 @@ use NewsExtractor::SiteSpecificExtractor::news_pts_org_tw;
 use NewsExtractor::SiteSpecificExtractor::www_twreporter_org;
 use NewsExtractor::SiteSpecificExtractor::new_ctv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::hk_crntt_com;
+use NewsExtractor::SiteSpecificExtractor::hk_on_cc;
+use NewsExtractor::SiteSpecificExtractor::www_xinhuanet_com;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -92,6 +94,8 @@ use constant {
         'www.twreporter.org' => 'NewsExtractor::SiteSpecificExtractor::www_twreporter_org',
         'new.ctv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::new_ctv_com_tw',
         'hk.crntt.com' => 'NewsExtractor::SiteSpecificExtractor::hk_crntt_com',
+        'hk.on.cc' => 'NewsExtractor::SiteSpecificExtractor::hk_on_cc',
+        'www.xinhuanet.com' => 'NewsExtractor::SiteSpecificExtractor::www_xinhuanet_com',
     },
     CSSRuleSetByHost => {
         'www.taiwannews.com.tw' => {
